ytsaurus-yson
A Rust library for serializing and deserializing the YSON format.
Re-exports
pub use crate::attributes::WithAttributes;pub use crate::de::StreamDeserializer;pub use crate::error::YsonError;pub use crate::node::YsonNode;pub use crate::node::YsonValue;pub use crate::scan::Scan;pub use crate::scan::scan_value;pub use crate::ser::YsonFormat;
Modules
- attributes
- Tools for working with YSON attributes and metadata.
- de
- Deserialization logic and types.
- error
- Error types and handling.
- node
- Abstract Syntax Tree (AST) representation of YSON values.
- scan
- Locating record boundaries in a partially-read buffer. Finding record boundaries without decoding.
- ser
- Serialization logic and types.
Functions
- from_
slice - Deserializes an instance of type
Tfrom a byte slice in the specified YSON format. - to_
string - Serializes the given value into a YSON-formatted string.
- to_vec
- Serializes the given value into a byte vector using the specified YSON format.